CookingTask class
Constructors
- CookingTask({required String label, required int totalSeconds})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRunning ↔ bool
-
getter/setter pair
- label ↔ String
-
getter/setter pair
- progress → double
-
no setter
- remainingSeconds ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timer ↔ Timer?
-
getter/setter pair
- timeString → String
-
no setter
- totalSeconds ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → void -
reset(
) → void -
start(
VoidCallback onTick) → void -
stop(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited