flower_fire library
A Flutter package for customizable UI components and utilities.
This package provides a collection of reusable widgets, utilities, and services for building Flutter applications. It includes components for:
- UI Widgets (animations, forms, etc.)
- Data Management (HTTP, WebSocket, etc.)
- Utilities (time conversion, unit conversion, etc.)
- Services (maps, weather, etc.)
To use this package, add it to your pubspec.yaml:
dependencies:
flower_fire: ^1.0.3
Then import the package:
import 'package:flower_fire/flower_fire.dart';
For more information, visit the GitHub repository.
Classes
- AddPetScreen
- Album
- AnimatedBallApp
- AnimatedBallScreen
- AQIApp
- AQIScreen
- AuthApp
- AuthScreen
- BMIApp
- BMIScreen
- BudgetManagerApp
- BudgetManagerScreen
- CalculatorApp
- CalculatorScreen
- CalorieBurnApp
- CalorieBurnScreen
- CartItem
- CartPage
- CheckoutPage
- CookingTask
- CookingTimerHome
- DailyJournalApp
- DrawingCanvas
- DrawingCanvasApp
- DrawnShape
- EcoHabitTrackerApp
- EmployeeApp
- EmployeeScreen
- Event
- EventFormScreen
- EventListScreen
- EventManagementApp
- Expense
- ExpenseListScreen
- ExpenseManagerApp
- FetchAlbumApp
- FitnessTrackerApp
- FitnessTrackerScreen
- FormValidationApp
- FormValidationScreen
- Habit
- HabitHomePage
- HotelSearchApp
- HotelSearchScreen
- ImageGallery
- ImageGalleryApp
- JournalScreen
- LocationApp
- LocationScreen
- Movie
- MovieCatalog
- MovieCatalogApp
- MovieCatalogScreen
- MovieDetail
- MovieRatingApp
- MyApp
- MyForm
- NewsApp
- NewsDetailScreen
- NewsListScreen
- NoteApp
- NotesScreen
- Pet
- PetCareApp
- PetListScreen
- Plant
- PlantCareApp
- PlantFormScreen
- PlantListScreen
- PostListScreen
- Product
- ProductListPage
- QuizApp
- RecipeApp
- RecipeScreen
- Shape
- ShapeDrawerScreen
- ShapeDrawingApp
- ShapePainter
- ShapePainterClass
- ShoppingApp
- SmartCookingTimerApp
- StudentListScreen
- StudentManagementApp
- TaskDialog
- Ticket
- TicketBookingApp
- TicketDialog
- TicketListScreen
- TimeZoneConverterApp
- TimeZoneConverterScreen
- Todo
- TodoApp
- TodoListScreen
- TodoScreen
- UnitConverterApp
- UnitConverterScreen
- VideoPlayerApp
- VideoPlayerScreen
- WeatherApp
- WeatherScreen
- WeatherScreenState
- WebSocketDemoApp
- WebSocketDemoHome
Enums
Functions
-
fetchAlbum(
) → Future< Album> -
initializeTimeZonesManually(
) → void